package com.lindosoft.android.tongue;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.view.ContextMenu;
import android.view.ContextMenu.ContextMenuInfo;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.ViewGroup;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.Toast;
import java.io.File;
import java.util.Collections;

/** Add/Remove folders. */
public class FoldersEdit extends AbstractFolders {
  @Override
  public boolean onContextItemSelected(MenuItem item) {
    AdapterView.AdapterContextMenuInfo info = (AdapterView.AdapterContextMenuInfo) item.getMenuInfo();
    ArrayAdapter<File> adapter = (ArrayAdapter<File>) getListAdapter();
    int menuItemIndex = item.getItemId();
    File folder = adapter.getItem(info.position);
    if (0 == menuItemIndex) {
      adapter.remove(folder);
      FolderModel.removeFolder(folder);
    } else if (1 == menuItemIndex) {
      renameFolder(folder);
    }
    return true;
  }
  
  @Override
  public void onCreateContextMenu(ContextMenu menu, View v, ContextMenuInfo menuInfo) {
    if (v != getListView()) {
      return;
    }
    AdapterView.AdapterContextMenuInfo info = (AdapterView.AdapterContextMenuInfo) menuInfo;
    ArrayAdapter<File> adapter = (ArrayAdapter<File>) getListAdapter();
    File folder = adapter.getItem(info.position);
    FolderModel.folder = folder;
    scroll(info.position);
    String[] menuItems = getResources().getStringArray(R.array.folders_context_menu);
    for (int i = 0; i<menuItems.length; i++) {
      menu.add(Menu.NONE, i, i, menuItems[i]);
    }
  }

  /** Folder add clicked. */
  public void onFolderAdd(View view) {
    AlertDialog.Builder alert = new AlertDialog.Builder(this);
    alert.setIcon(R.drawable.folder_add);
    alert.setTitle(R.string.alert_title_folder_add);
    LayoutInflater inflater = (LayoutInflater) getSystemService(Context.LAYOUT_INFLATER_SERVICE);
    final EditText editText = (EditText) inflater.inflate(R.layout.folder_add, null);
    alert.setView(editText);
    alert.setPositiveButton(R.string.alert_ok_folder_add, new DialogInterface.OnClickListener() {
      public void onClick(DialogInterface dialog, int whichButton) {
        String name = editText.getText().toString();
        if (0 == name.length()) {
          Toast.makeText(FoldersEdit.this, R.string.toast_folder_add, Toast.LENGTH_LONG).show();
        } else {
          FolderModel.addFolder(name);
          Intent intent = new Intent(FoldersEdit.this, TonguesEdit.class);
          startActivity(intent);
        }
      }
    });
    alert.show();
  }


  @Override
  protected int getContentViewId() {
    return R.layout.folders_edit;
  }
  
  @Override
  protected void onListItemClick(ListView l, View v, int position, long id) {
    ArrayAdapter<File> adapter = (ArrayAdapter<File>) getListAdapter();
    File folder = adapter.getItem(position);
    FolderModel.folder = folder;
    Intent intent = new Intent(this, TonguesEdit.class);
    startActivity(intent);
  }

  /** Rename folder. */
  public void renameFolder(final File folder) {
    AlertDialog.Builder alert = new AlertDialog.Builder(this);
    alert.setIcon(R.drawable.folder);
    alert.setTitle(R.string.alert_title_folder_rename);
    LayoutInflater inflater = (LayoutInflater) getSystemService(Context.LAYOUT_INFLATER_SERVICE);
    final EditText editText = (EditText) inflater.inflate(R.layout.folder_rename, null);
    final String nameOld = folder.getName();
    editText.setText(nameOld);
    alert.setView(editText);
    alert.setPositiveButton(R.string.alert_ok_folder_rename, new DialogInterface.OnClickListener() {
      public void onClick(DialogInterface dialog, int whichButton) {
        String name = editText.getText().toString();
        if (0 == name.length() || name.equalsIgnoreCase(nameOld)) {
          return;
        }
        File folderNew = new File(folder.getParentFile(), name);
        if(folder.renameTo(folderNew)) {
          FolderModel.folders.remove(folder);
          FolderModel.folders.add(folderNew);
          FolderModel.folder = folderNew;
          Collections.sort(FolderModel.folders);
          ArrayAdapter<File> adapter = (ArrayAdapter<File>) getListAdapter();
          adapter.clear();
          for (File folder : FolderModel.folders) {
            adapter.add(folder);
          }
          scroll(adapter.getPosition(FolderModel.folder));
        }
      }
    });
    alert.show();
  }
}