package com.lindosoft.android.tongue;

import android.app.Activity;
import android.content.CursorLoader;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.provider.MediaStore;
import android.view.View;
import android.widget.EditText;
import android.widget.Toast;
import java.io.File;

/** Edit tongue. */
public class TongueEdit extends Activity {
  public final int TONGUE_EDIT_FOREIGN = 222;
  public final int TONGUE_EDIT_NATIVE = 333;
  
  @Override
  protected void onActivityResult(int requestCode, int resultCode, Intent data) {
    if (RESULT_OK != resultCode) {
      return;
    }
    File from = new File(getPath(data.getData()));
    if (TONGUE_EDIT_FOREIGN == requestCode) {
      String videoForeign = TongueModel.tongue.getId() + "VideoForeign." + getExtension(from.getAbsolutePath());
      File to = new File(FolderModel.folder, videoForeign);
      //Toast.makeText(this, from + " " + to, Toast.LENGTH_LONG).show();
      from.renameTo(to);
      TongueModel.tongue.videoForeign = videoForeign;
    }
    if (TONGUE_EDIT_NATIVE == requestCode) {
      String videoNative = TongueModel.tongue.getId() + "VideoNative." + getExtension(from.getAbsolutePath());
      File to = new File(FolderModel.folder, videoNative);
      //Toast.makeText(this, from + " " + to, Toast.LENGTH_LONG).show();
      from.renameTo(to);
      TongueModel.tongue.videoNative = videoNative;
    }    
  }
  
  @Override
  public void onBackPressed() {
    writeTongue();
    super.onBackPressed();
  }

  
  /** Video Foreign clicked. */
  public void onVideoForeign(View view) {
    Intent intent = new Intent(MediaStore.ACTION_VIDEO_CAPTURE);
    startActivityForResult(intent, TONGUE_EDIT_FOREIGN);
  }

  /** Video native clicked. */
  public void onVideoNative(View view) {
    Intent intent = new Intent(MediaStore.ACTION_VIDEO_CAPTURE);
    startActivityForResult(intent, TONGUE_EDIT_NATIVE);
  }

  /** Ready clicked. */
  public void onReady(View view) {
    writeTongue();
    finish();
  }

  @Override
  protected void onCreate(Bundle savedInstanceState) {
    super.onCreate(savedInstanceState);
    setContentView(R.layout.tongue_edit);
  }

  @Override
  protected void onPause() {
    writeNames();
    super.onPause();
  }

  @Override
  protected void onResume() {
    super.onResume();
    EditText nameForeign = (EditText) findViewById(R.id.edit_name_foreign);
    nameForeign.setText(TongueModel.tongue.nameForeign);
    EditText nameNative = (EditText) findViewById(R.id.edit_name_native);
    nameNative.setText(TongueModel.tongue.nameNative);
  }


  /** Get extension. */
  private String getExtension(String name) {
    return name.substring(name.lastIndexOf("."));
  }
  
  /** Get path from video uri. */
  public String getPath(Uri uri) {
    String[] projection = { MediaStore.Video.Media.DATA };
    CursorLoader loader = new CursorLoader(this, uri, projection, null, null, null);
    Cursor cursor = loader.loadInBackground();
    startManagingCursor(cursor);
    int columnIndex = cursor.getColumnIndexOrThrow(projection[0]);
    cursor.moveToFirst();
    return cursor.getString(columnIndex);
  }
  
  /** Write names. */
  private void writeNames() {
    EditText nameForeign = (EditText) findViewById(R.id.edit_name_foreign);
    TongueModel.tongue.nameForeign = nameForeign.getText().toString().trim().replace('/', '_');
    EditText nameNative = (EditText) findViewById(R.id.edit_name_native);
    TongueModel.tongue.nameNative = nameNative.getText().toString().trim().replace('/', '_');
  }

  /** Write tongue. */
  private void writeTongue() {
    writeNames();
    try {
      TongueModel.writeTongues();
    } catch (Exception ex) {
      Toast.makeText(this, "writeTongues(): " + ex, Toast.LENGTH_LONG).show();
    }
  }
}