package com.lindosoft.android.tongue;

import android.os.Environment;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileOutputStream;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Random;

/** Shared tongue data. */
public class TongueModel {
  public static final String FILENAME = "lindotongue.txt";
  public static final String SEPARATOR = "/";
  public static Tongue tongue = null;
  public static List<Tongue> tongues = new ArrayList<Tongue>();

  /** Add tongue. */
  public static void addTongue() throws Exception {
    int idMax = 0;
    for (Tongue tongueTemp : tongues) {
      idMax = Math.max(idMax, tongueTemp.id);
    }
    tongue = new Tongue();
    tongue.id = idMax + 1;
    tongues.add(tongue);
    writeTongues();
  }
          
  /** Set next tongue. */
  public static void nextTongue() {
    if (0 == tongues.size()) {
      tongue = null;
      return;
    }
    if (null == tongue || -1 == tongues.indexOf(tongue) || tongues.size() - 1 == tongues.indexOf(tongue)) {
      tongue = tongues.get(0);
    } else {
      tongue = tongues.get(tongues.indexOf(tongue) + 1);
    }
  }

  /** Set previous tongue. */
  public static void previousTongue() {
    if (0 == tongues.size()) {
      tongue = null;
      return;
    }
    if (null == tongue || 1 > tongues.indexOf(tongue)) {
      tongue = tongues.get(tongues.size() - 1);
    } else {
      tongue = tongues.get(tongues.indexOf(tongue) - 1);
    }
  }

  /** Read tongues. */
  public static void readTongues() throws Exception {
    List<Tongue> tonguesTemp = new ArrayList<Tongue>();
    File file = new File(FolderModel.folder, FILENAME);
    if (!file.isFile()) {
      file.createNewFile();
    }
    BufferedReader reader = new BufferedReader(new FileReader(file));
    try {
      String line = null;
      while (null != (line = reader.readLine())) {
        tonguesTemp.add(readTongue(line));
      }
    } finally {
      reader.close();
      reader = null;
    }
    Collections.sort(tonguesTemp);
    tongues.clear();
    tongues.addAll(tonguesTemp);
  }

  /** Remove tongue. */
  public static void removeTongue(Tongue tongueTemp) throws Exception {
    tongue = null;
    tongues.remove(tongueTemp);
    new File(FolderModel.folder, tongueTemp.videoForeign).delete();
    new File(FolderModel.folder, tongueTemp.videoNative).delete();
    writeTongues();
  }

  /** Shuffle tongues. */
  public static void shuffleTongues() {
    if (MainModel.shuffle) {
      Collections.shuffle(tongues, new Random(System.currentTimeMillis()));
    }
  }

  /** Write tongues. */
  public static void writeTongues() throws Exception {
    Collections.sort(tongues);
    File file = new File(FolderModel.folder, FILENAME);
    PrintWriter writer = new PrintWriter(file, "UTF-8");
    try {
      for (Tongue tongueTemp : tongues) {
        writeTongue(tongueTemp, writer);
      }
    } finally {
      writer.close();
      writer = null;
    }
  }


  /** Read tongue. */
  private static Tongue readTongue(String line) {
    String[] tokens = line.split(SEPARATOR, -1);
    Tongue tongueTemp = new Tongue();
    tongueTemp.id = Integer.parseInt(tokens[0]);
    tongueTemp.nameForeign = tokens[1];
    tongueTemp.nameNative = tokens[2];
    tongueTemp.videoForeign = tokens[3];
    tongueTemp.videoNative = tokens[4];
    return tongueTemp;
  }

  /** Write tongue. */
  private static void writeTongue(Tongue tongue, PrintWriter writer) {
    writer.println(tongue.id
        + SEPARATOR + tongue.nameForeign + SEPARATOR + tongue.nameNative
        + SEPARATOR + tongue.videoForeign + SEPARATOR + tongue.videoNative);
    writer.flush();
  }
}