package com.lindosoft.android.tongue;

import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
import android.view.ContextMenu;
import android.view.ContextMenu.ContextMenuInfo;
import android.view.Menu;
import android.view.MenuItem;
import android.view.ViewGroup;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

/** Add/Remove tongues. */
public class TonguesEdit extends AbstractList {
  @Override
  public boolean onContextItemSelected(MenuItem item) {
    AdapterView.AdapterContextMenuInfo info = (AdapterView.AdapterContextMenuInfo) item.getMenuInfo();
    ArrayAdapter<Tongue> adapter = (ArrayAdapter<Tongue>) getListAdapter();
    int menuItemIndex = item.getItemId();
    Tongue tongue = adapter.getItem(info.position);
    if (0 == menuItemIndex) {
      TongueModel.tongue = tongue;
      Intent intent = new Intent(this, TongueEdit.class);
      startActivity(intent);
    } else if (1 == menuItemIndex) {
      adapter.remove(tongue);
      try {
        TongueModel.removeTongue(tongue);
      } catch (Exception ex) {
        Toast.makeText(this, "removeTongue(" + tongue + "): " + ex, Toast.LENGTH_LONG).show();
      }
    }
    return true;
  }
  
  @Override
  public void onCreateContextMenu(ContextMenu menu, View v, ContextMenuInfo menuInfo) {
    if (v != getListView()) {
      return;
    }
    AdapterView.AdapterContextMenuInfo info = (AdapterView.AdapterContextMenuInfo) menuInfo;
    ArrayAdapter<Tongue> adapter = (ArrayAdapter<Tongue>) getListAdapter();
    Tongue tongue = adapter.getItem(info.position);
    TongueModel.tongue = tongue;
    scroll(info.position);
    String[] menuItems = getResources().getStringArray(R.array.tongues_context_menu);
    for (int i = 0; i<menuItems.length; i++) {
      menu.add(Menu.NONE, i, i, menuItems[i]);
    }
  }

  /** Tongue add clicked. */
  public void onTongueAdd(View view) {
    try {
      TongueModel.addTongue();
      Intent intent = new Intent(this, TongueEdit.class);
      startActivity(intent);
    } catch (Exception ex) {
      Toast.makeText(this, "addTongue(): " + ex, Toast.LENGTH_LONG).show();
    }
  }

  @Override
  protected void onListItemClick(ListView l, View v, int position, long id) {
    ArrayAdapter<Tongue> adapter = (ArrayAdapter<Tongue>) getListAdapter();
    Tongue tongue = adapter.getItem(position);
    TongueModel.tongue = tongue;
    TongueModel.previousTongue();
    Intent intent = new Intent(this, TonguesNative.class);
    startActivity(intent);
  }

  @Override
  protected void onCreate(Bundle savedInstanceState) {
    super.onCreate(savedInstanceState);
    setContentView(R.layout.tongues_edit);
    ArrayAdapter<Tongue> adapter = new ArrayAdapter<Tongue>(this, R.layout.tongues_item, R.id.label) {
      public View getView(int position, View convertView, ViewGroup parent) {
        View view = super.getView(position, convertView, parent);
        TextView label = (TextView) view.findViewById(R.id.label);
        label.setText(TongueModel.tongues.get(position).toString());
        if (null != TongueModel.tongue && position == getPosition(TongueModel.tongue)) {
          view.setBackgroundColor(Color.DKGRAY);
        } else {
          view.setBackgroundColor(Color.BLACK);
        }
        return view;
      }
		};
    setListAdapter(adapter);
    registerForContextMenu(getListView());
  }
  
  @Override
  protected void onResume() {
    super.onResume();
    try {
      TongueModel.readTongues();
    } catch (Exception ex) {
      Toast.makeText(this, "readTongues(): " + ex, Toast.LENGTH_LONG).show();
    }
    ArrayAdapter<Tongue> adapter = (ArrayAdapter<Tongue>) getListAdapter();
    adapter.clear();
    for (Tongue tongue : TongueModel.tongues) {
      adapter.add(tongue);
    }
    //adapter.addAll(TongueModel.tongues);
    scroll(adapter.getPosition(TongueModel.tongue));
  }
}